@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2011-2012 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -93,8 +94,7 @@ void ExportToHtmlDialog::set_export_linked_all(bool value)
 void ExportToHtmlDialog::save_preferences()
 {
   std::string dir = sharp::file_dirname(get_filename());
-  Glib::RefPtr<Gio::Settings> settings = gnote::Preferences::obj()
-    .get_or_load_schema_settings(SCHEMA_EXPORTHTML);
+  Glib::RefPtr<Gio::Settings> settings = gnote::Preferences::obj().get_schema_settings(SCHEMA_EXPORTHTML);
   settings->set_string(EXPORTHTML_LAST_DIRECTORY, dir);
   settings->set_boolean(EXPORTHTML_EXPORT_LINKED, get_export_linked());
   settings->set_boolean(EXPORTHTML_EXPORT_LINKED_ALL, get_export_linked_all());
@@ -103,8 +103,7 @@ void ExportToHtmlDialog::save_preferences()
 
 void ExportToHtmlDialog::load_preferences(const std::string & default_file)
 {
-  Glib::RefPtr<Gio::Settings> settings = gnote::Preferences::obj()
-    .get_or_load_schema_settings(SCHEMA_EXPORTHTML);
+  Glib::RefPtr<Gio::Settings> settings = gnote::Preferences::obj().get_schema_settings(SCHEMA_EXPORTHTML);
   std::string last_dir = settings->get_string(EXPORTHTML_LAST_DIRECTORY);
   if (last_dir.empty()) {
     last_dir = Glib::get_home_dir();
